@@ -31,48 +31,69 @@ def tonicDNSClient(uri, method, token, data, keyword='', domain=''):
     elif sys.version_info > (3, 0):
         import urllib.request as urllib
 
-    encoded = json.JSONEncoder().encode(data)
-    o = urllib.build_opener(urllib.HTTPHandler)
-    r = urllib.Request(uri, data=encoded.encode('utf-8'))
-
-    r.add_header('x-authentication-token', token)
+    encoded = json.JSONEncoder(object).encode(data)
+    obj = urllib.build_opener(urllib.HTTPHandler)
+    req = urllib.Request(uri, data=encoded.encode('utf-8'))
+    req.add_header('x-authentication-token', token)
 
     # When encoded(=data) is False, retrieve data as GET method.
     if encoded:
-        r.add_header('Content-Type', 'application/json')
+        req.add_header('Content-Type', 'application/json')
+
+    req.get_method = lambda: method
 
-    r.get_method = lambda: method
     try:
-        url = o.open(r)
+        res = obj.open(req)
+
     except urllib.HTTPError as e:
         sys.stderr.write("ERROR: %s\n" % e)
         exit(1)
 
     # response body
     if method == 'GET':
-        datas = json.loads(url.read().decode('utf-8'))
+
+        data = res.read()
+        datas = json.loads(data.decode('utf-8'))
+
         # filtering with keyword
         if keyword == 'serial':
             from converter import JSONConvert
             record = searchRecord(datas, 'SOA')[0]
+
+            # if SOA record, remove priority unnecessary
             del record['priority']
+
+            # override ttl
             record['ttl'] = int(record['ttl'])
+
             c = JSONConvert(domain)
             new_record = c.getSOA(record)
             return record, new_record
+
+        # '--search' option of 'get' subcommand
         elif keyword:
             records = searchRecord(datas, keyword)
             datas.update({"records": records})
+
+        # 'tmpl_get' subcommand
         if uri.split('/')[3] == 'template':
+
+            # when specify template identfier
             if len(uri.split('/')) == 5:
                 formattedPrint(datas)
+
+            # when get all templates
             else:
                 for data in datas:
                     formattedPrint(data)
+
+        # 'get' subcommand
         else:
             formattedPrint(datas)
+
+    # response non JSON data
     else:
-        data = url.read()
+        data = res.read()
         print(data)
 
 
@@ -82,53 +103,92 @@ def formattedPrint(datas):
         import utils2 as utils
     elif sys.version_info > (3, 0):
         import utils3 as utils
+
     if not datas:
         print("No data")
         exit(1)
+
     if datas.get('records'):
         print("domain: %(name)s" % datas)
+
         if datas.get('type') == 'MASTER':
             print("serial: %(notified_serial)s" % datas)
+
         print("DNS   : %(type)s" % datas)
+
+        # header
         hr()
         print('%-33s %-5s %-25s %-5s %-3s'
               % ('name', 'type', 'content', 'ttl', 'prio'))
         hr()
+
         for record in datas.get('records'):
+
+            # print 'NAME'
             utils.print_inline("%(name)-33s" % record)
+
+            # print 'TYPE' of SOA record
             if record.get('type') == 'SOA':
                 print("%(type)-5s" % record)
+
+            # print 'TYPE' of non SOA record
             else:
                 utils.print_inline("%(type)-5s" % record)
+
+            # print 'CONTENT' of non SOA
             if record.get('type') == 'SOA':
                 utils.print_inline(">\t\t%(content)-25s " % record)
+
+            # print 'CONTENT' of SOA record
             else:
                 utils.print_inline("%(content)-25s" % record)
+
+            # print TTL, and PRIORITY for MX, SRV record
             if record.get('priority'):
                 utils.print_inline("%(ttl)5s" % record)
                 print("%(priority)2s" % record)
+
+            # print ttl for non SOA record
             else:
                 print("%(ttl)5s " % record)
+
         hr()
+
+    # for template
     elif datas.get('identifier'):
         print("identifier : %(identifier)s" % datas)
         print("description: %(description)s" % datas)
         hr()
         print('%-33s %-5s %-25s %-5s %-3s'
               % ('name', 'type', 'content', 'ttl', 'prio'))
+
         for record in datas.get('entries'):
+
+            # print 'NAME'
             utils.print_inline("%(name)-33s" % record)
+
+            # print 'TYPE' for SOA
             if record.get('type') == 'SOA':
                 print("%(type)-5s" % record)
+
+            # print 'TYPE' for non SOA
             else:
                 utils.print_inline("%(type)-5s" % record)
+
+            # print 'CONTENT' for SOA
             if record.get('type') == 'SOA':
                 utils.print_inline("> %(content)-25s " % record)
+
+            # print 'CONTENT' for non SOA
             else:
                 utils.print_inline("%(content)-24s" % record)
+
+            # print 'TTL', and 'PRIORITY'
             if record.get('priority') != None:
                 utils.print_inline("%(ttl)5s" % record)
                 print("%(priority)2s" % record)
+
+            # print
             else:
                 print("%(ttl)5s " % record)
         hr()
@@ -136,6 +196,7 @@ def formattedPrint(datas):
         print("No match records")
 
 
+# print horizontal line
 def hr():
     print('=' * 78)
 
@@ -150,12 +211,15 @@ def createZoneRecords(server, token, domain, data, identifier):
     # x-authentication-token: token
     method = 'PUT'
     uri = 'https://' + server + '/zone'
+
     for i, v in enumerate(data):
+
         if i == 0:
             from converter import JSONConvert
-            o = JSONConvert(domain)
-            zone = o.generateZone(domain, identifier, v)
+            obj = JSONConvert(domain)
+            zone = obj.generateZone(domain, identifier, v)
             tonicDNSClient(uri, method, token, zone)
+
         else:
             # method: PUT
             uri = 'https://' + server + '/zone/' + domain
@@ -275,9 +339,12 @@ def searchRecord(datas, keyword):
     # either key and type, or on the other hand
     # data is dictionaly
     result = []
+
     for record in datas['records']:
+
         if record['name'].find(keyword) >= 0 or \
                 record['content'].find(keyword) >= 0 or \
                 record['type'] == keyword:
             result.append(record)
+
     return result
